audb
====

.. automodule:: audb

available
---------

.. autofunction:: available

cached
------

.. autofunction:: cached

config
------

.. autoclass:: config
    :members:

Dependencies
------------

.. autoclass:: Dependencies
    :members:
    :special-members:

default_cache_root
------------------

.. autofunction:: default_cache_root

dependencies
------------

.. autofunction:: dependencies

exists
------

.. autofunction:: exists

Flavor
------

.. autoclass:: Flavor
    :members:
    :special-members:

flavor_path
-----------

.. autofunction:: flavor_path

latest_version
--------------

.. autofunction:: latest_version

load
----

.. autofunction:: load

load_to
-------

.. autofunction:: load_to

publish
-------

.. autofunction:: publish

remove_media
------------

.. autofunction:: remove_media

Repository
----------

.. autoclass:: Repository
    :members:

repository
----------

.. autofunction:: repository

versions
--------

.. autofunction:: versions
